@@ -139,7 +139,7 @@ class CloudPods:
             return None
 
     @enter_and_leave_function
-    def create_server_by_guest_image(self,guest_image_id,disk_image_id,arch, disk_size, disks, nets_list, vm_name, sku="",count=1,reset_new_password="",hypervisor="kvm",bios="bios",cpu=256,mem=2097152):
+    def create_server_by_guest_image(self,guest_image_id,disk_image_id,arch, disk_size, disks, nets_list, vm_name, sku="",count=1,reset_new_password="",hypervisor="kvm",bios="bios",cpu=256,mem=2097152,storage_medium_type="ssd"):
         nets=[{"network": net} for net in nets_list]
         server = {
             "auto_start": True,
@@ -158,14 +158,14 @@ class CloudPods:
             server["sku"] = sku
             server["schedtags"] = [{"id": "094cfe0f-7fbf-451f-879d-d44151539240", "strategy": "exclude"}]
             server["disks"] = [{"disk_type": "sys", "index": 0, "backend": "local", "size": disk_size, "image_id": disk_image_id,
-                       "medium": "ssd"}]
+                       "medium": storage_medium_type}]
             for i in range(len(disks)):
                 disk = dict({})
                 disk["disk_type"] = "data"
                 disk["index"] = i + 1
                 disk["backend"] = "local"
                 disk["size"] = int(disks[i]) * 1024
-                disk["medium"] = "ssd"
+                disk["medium"] = storage_medium_type
                 server["disks"].append(disk)
         if hypervisor == "baremetal":
             server["disks"] = [
@@ -175,7 +175,7 @@ class CloudPods:
             server["vcpu_count"]=cpu
             server["vmem_size"]=mem
             server["baremetal_disk_configs"]=[
-                        {"conf":"none","driver":"PCIE","count":1,"range":[0],"adapter":0,"type":"ssd"}
+                        {"conf":"none","driver":"PCIE","count":1,"range":[0],"adapter":0,"type":storage_medium_type}
                       ]
         if reset_new_password:
             server["password"]=reset_new_password
